@@ -22,8 +22,6 @@ package main
 import (
 	"flag"
 	"fmt"
-	"math/rand"
-	"time"
 	"github.com/dustinkirkland/golang-petname"
 )
 
@@ -32,12 +30,7 @@ var (
 	separator = flag.String("separator", "-", "The separator between words in the pet name")
 )
 
-func init() {
-	rand.Seed(time.Now().UTC().UnixNano())
-}
-
 func main() {
 	flag.Parse()
-	rand.Seed(time.Now().UnixNano())
 	fmt.Println(petname.Generate(*words, *separator))
 }
